# xdow
<p>view on <a href="https://github.com/pankajthekush/xdow">github</a> </p>
<p>Video Downloader (Mostly Porn)</p>
<p>This is a video downloader for porn. To download youtube videos you
can use <a href="https://pypi.org/project/youtube_dl/">youtube-dl</a> </p>
<br>
<br>
<h2>How to use</h2>
<p>Get Direct link of any video and pass the link as argument to console script <b>xdow</b></p>
<p>e.g</p>
<code>xdow https://www.pornhub.com/view_video.php?viewkey=ph5e5afa917d4fd</code>
<br>
<br>
<p>Please report bug by raising a issue at <a href="https://github.com/pankajthekush/xdow/issues">github issues</a>
or sending me an email by clicking the author hyperlink</p>

<p>-------------------------------------------------------</p>

<h2>Websites Supported </h2>
<ul>
<li><a href="www.pornhub.com">pornhub.com</a></li>
<li><a href="www.pornhub.org">pornhub.org</a></li>
</ul>

<h2>OS/Python Support</h2>
<ul>
<li>Windows 10</li>
<li>Python 3.7</li>
</ul>
